@@ -94,7 +94,7 @@ def init():
     print("Your current directory  is : ", path)
     os.chdir(path)
     try:
-        a_yaml_file = open("./config.yaml")
+        a_yaml_file = open("config.yaml")
         parsed_yaml_file = yaml.load(a_yaml_file, Loader=yaml.FullLoader)
         project_id=parsed_yaml_file["project_id"]
 
@@ -180,17 +180,3 @@ if __name__ == "__main__":
     server.serve_forever()
 
 
-
-import requests
-# Making a get request
-response = requests.get('http://35.225.89.124/push_commit')
-# print response
-print(response)
-# print elapsed time
-print(response.elapsed)
-
-from time import time, sleep
-while True:
-    sleep(60 - time() % 60)
-	# thing to run
-
